/*************************************************************
Generated for Telelogic Tau 4.2.0.2.13102 at Thu Apr 16 19:56:55 MEST 2009
Licensed Materials - Property of IBM 
 Copyright IBM Corporation 2002,2008.  All Rights Reserved.

U.S. Government Users Restricted Rights:  Use, duplication or disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
*************************************************************/
#ifndef GEN_3HdbJIHdvWBLTQfkqILgurFE
#define GEN_3HdbJIHdvWBLTQfkqILgurFE

#if defined(TOR_USE_INSTRUMENTATION) && !defined(TOR_NO_EVENTMANAGER)

#include "torPlatform.h"

#include "tor.h"
#include "torContainers.h"
#include "torTypes.h"
#include "torEventMedia.h"
#include "torCoders.h"
#include "torMetaEvents.h"
#include "torMetaStackContext.h"

namespace tor {
    namespace meta {
        class EventManager_initialize;

        class TOR_EXT_DEF EventManager : public EventReceiver {
        public:
            // Called when the event manager receives an event.
            virtual bool receive(tor::Event* e);

            // Register an EventMedia. Note that the responsibility for deleting the event media.
            // is taken by the EventManager.
            // This function is synchronized.
            void registerMedia(EventMedia* m);

            // Unregister an EventMedia. Note that the responsibility for deleting the event media
            // is passed over to the caller.
            // This function is synchronized.
            void unregisterMedia(EventMedia* m);

            // These functions unregisters all eventmedias of the specified kind and deletes them.
            // These functions are synchronized.
            void deleteAllLogFiles();
            void deleteAllHostTracers();

            // These functions creates a new event media of the specified kind and registers it.
            void createNewLogFile(const char* path);
            void createNewHostTracer();

            // Set the code to use for encoding metadata. Default is to use an U2P coder.
            // This function is synchronized.
            void setCoder(Coder* c);

            // Returns the default coder of the event manager.
            Coder& getDefaultCoder();

            // Toggle whether the EventManager shall be active or not.
            // It is initially active.
            // When the EventManager is inactive no meta events from the application are processed.
            // This function is synchronized.
            void setActive(tor::Boolean a);

            // Returns true if the EventManager is currently active, false otherwise.
            // This function is synchronized.
            bool isActive();

            // Encodes the meta event and sends it to this EventManager for synchronous or
            // asynchronous processing (depending on the synchroneous flag).
            void processEvent(tor::meta::Event* event);

            // Returns the ThreadInfo representing the thread with the specified id.
            // If no ThreadInfo exists for the specified thread (happens the first time
            // this function is called for a thread), a ThreadInfo structure will be added for
            // the thread first (hence, NULL is never returned from this function).
            // This function is synchronized.
            ThreadInfo* getThreadInfo(int threadId);           

            // Returns true if the eventManager has been finalized (happens when the application is terminating).
            bool isFinalized();

            // Finalizes the eventManager explicitly and immediately.
            void finalize();

            // Initializes the eventManager explicitly and immediately.
            void initialize();

            // This function shall be called before executing an instrumented action (with the specified GUID).
            // It checks if a breakpoint has been hit. If so, the necessary debug events are triggered.
            // It also updates the current execution point.
            // If an action contains calls to operations, this function shall also be called when execution
            // has just returned from these calls. In those cases, the action is partially already 
            // executed, and the partiallyAlreadyExecuted flag should be set to true to indicate that.
            // This function is synchronized.
            void beforeAction(const Charstring& strGuid, bool partiallyAlreadyExecuted = false);

        protected:
            // Emits the string-encoded data of the event over all registered medias.
            void emitToMedia(tor::meta::Event* e);

            // Determines if the eventManager should wait at start-up for an attach signal (i.e. if the newly
            // started application should be debugged). 
            // In either case, the host and port parameters are set-up with
            // values specifying how to communicate with the host debugger.
            // Note that this is done even if the eventManager should not wait for an initial attach.
            // In order to be able to respond to a later attach the host and port must be known anyway.
            bool shouldWaitForAttach(Charstring& host, Natural& port);

            // Removes all pseudo breakpoints.
            // This function is synchronized.
            void removeAllPseudoBreakpoints();

            // Called when a meta event has been processed.
            // If needed, all user threads are unblocked to let the application continue executing.
            // This function is synchronized.
            void continueApplication(tor::Event* event);

            // Blocks all user threads except the one with the specified thread id.
            // This function is synchronized.
            void blockAllThreadsExceptOne(int threadId);

            // Returns the current execution point, i.e. the GUID of the action currently being executed 
            // by the active thread of the application.
            // This function is synchronized.
            Charstring& getCurrentExecutionPoint();

            // Returns ThreadInfo for a thread that is in the active debug context. If more than one such thread exists,
            // any of them may be returned. If no thread is active, the first one is set to active and returned.
            ThreadInfo* _getActiveThread();

            ThreadInfo* _getThreadInfo(int threadId);

            // Call-backs for commands invoked by the host debugger.
            void onStep();
            void onStepIn();
            void onStepOut();
            void onRunTo(const Charstring& actionGuid);
            void onBreak();

            // Set the specified breakpoints.
            // This function is synchronized.
            void setBreakpoints(String<BreakpointInfo>& breakpointsToSet);

            // Remove the specified breakpoints. If the string is empty, all breakpoints will be removed.
            // This function is synchronized.
            void removeBreakpoints(String<BreakpointInfo>& breakpointsToRemove);

            // Returns information about the running application.
            AppInfo getAppInfo();

        public:
            EventManager();
            virtual ~EventManager();

            Coder* coder;            

            tor::Boolean active;
            tor::Boolean synchronous;

            friend class EventManagerImpl;
            friend class EventManagerImpl_initialize;            

            typedef std::map<Charstring, BreakpointInfo> BreakpointMap;
        private:
            // Beware: No value members with destructors in this class, since its destructor is called multiple times!

            class EventManagerImpl* emImpl;     // Private behavior

            struct EventManagerData {
                EventManagerData() 
                  : m_breakpointMap(),
                    m_pseudoBreakpoint(0),
                    m_mutex()
                {
                    m_mutex.init();
                }

                ~EventManagerData() {}

                BreakpointMap m_breakpointMap;               // Map of actions (guids) for which a breakpoint currently is set    
                struct PseudoBreakpoint* m_pseudoBreakpoint; // A pseudo-breakpoint structure, or NULL is no pseudo-breakpoint currently is set
                os::Mutex m_mutex;                           // A mutex for protecting the data
            } *m_data;  // Private data           

        };

        TOR_EXT_DEF extern EventManager eventManager;

        // The purpose of EventManagerInit is to force the event manager to be initialized 
        // before and finalized after any object in the user application!
        
        struct TOR_EXT_DEF EventManagerInit {
            EventManagerInit();
            ~EventManagerInit();
        };

        static EventManagerInit instance;
    }

    //////////////////////////////////////////////////////////////////////////
    // Some useful utilities for sending tor::meta::Message events.
    //////////////////////////////////////////////////////////////////////////

    // Trace a message.
    TOR_EXT_DEF void trace(const Charstring& message);

    // If the condition evaluates to false, trace a message indicating an assertion failure.     
    // Otherwise do nothing.
#define TOR_ASSERT(E) (void) (E || (::tor::assertFailure(_T(#E), _T(__FILE__), __LINE__), 0))

    // Report an assertion failure for the condition at the specified line in the specified file.
    TOR_EXT_DEF void assertFailure(const TCHAR* condition, const TCHAR* file, int line);

}

#endif 

#endif /*INCLUDE PROTECTION*/

