<?xml version="1.0" ?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">

<xsl:template name="Image">
  <xsl:param name="version"/>
  <xsl:for-each select="image">
    <xsl:if test = ".=$version">
      <center><img scale="100%"><xsl:attribute name="src"><xsl:value-of select="@src"/></xsl:attribute></img></center>
    </xsl:if>
  </xsl:for-each>
</xsl:template>

<xsl:template name="Text">
  <xsl:param name="version"/>
  <xsl:for-each select="unparsed-text">
    <xsl:if test = "@version=$version">
      <center><xsl:value-of select="."/></center>
    </xsl:if>
  </xsl:for-each>
</xsl:template>

<xsl:template match="/">

<xsl:variable name="has-ancestor" select="/report/diagram-compare[@mode!='2-way']"/>
<xsl:variable name="has-ancestor2" select="/report/diagram-compare[@mode='4-way']"/>

<html>
<head>
  <title>Compare review - diagram-centric example stylesheet</title>
</head>
<body>
<h1><xsl:element name="a"><xsl:attribute name="href">tlog://&lt;<xsl:value-of select="/report/diagram-compare/project"/>&gt;</xsl:attribute>Difference table</xsl:element></h1>
    <xsl:for-each select="/report/diagram-compare/representative-diagram">
      <h2><xsl:value-of select="name"/></h2>
      <table border="1" cellpadding="2" cellspacing="0" frame = "box">
        <tr>
          <th>Id</th>
          <th>Diff</th>
          <th>Version 1</th>
          <th>Version 2</th>
          <xsl:if test="$has-ancestor">
            <th>Ancestor</th>
          </xsl:if>
          <xsl:if test="$has-ancestor2">
            <th>Alternative Ancestor</th>
          </xsl:if>
        </tr>
        <tr>
        <td></td>
        <td>Overview images</td>
        <xsl:for-each select="image">
          <xsl:if test = ".='overview_version1'">
            <td>
              <center><img scale="100%"><xsl:attribute name="src"><xsl:value-of select="@src"/></xsl:attribute></img></center>
            </td>
          </xsl:if>
          <xsl:if test = ".='overview_version2'">
            <td>
              <center><img scale="100%"><xsl:attribute name="src"><xsl:value-of select="@src"/></xsl:attribute></img></center>
            </td>
          </xsl:if>
          <xsl:if test = ".='overview_ancestor'">
            <td>
              <center><img scale="100%"><xsl:attribute name="src"><xsl:value-of select="@src"/></xsl:attribute></img></center>
            </td>
          </xsl:if>
          <xsl:if test = ".='overview_ancestor2'">
            <td>
              <center><img scale="100%"><xsl:attribute name="src"><xsl:value-of select="@src"/></xsl:attribute></img></center>
            </td>
          </xsl:if>
        </xsl:for-each>
        </tr>
        <xsl:for-each select="composite-difference">
           <tr>
              <td rowspan="{count(created|modified|deleted|movedFrom|movedTo|conflict)+1}"><xsl:value-of select="@id"/></td>
              <td rowspan="{count(created|modified|deleted|movedFrom|movedTo|conflict)+1}"><xsl:value-of select="description"/></td>
           </tr>
           <xsl:for-each select="created|modified|deleted|movedFrom|movedTo|conflict">
              <tr>
                 <xsl:choose>
                    <xsl:when test = "local-name()='conflict'">
                       <xsl:for-each select="created[version=1]|modified[version=1]|deleted[version=1]|movedFrom[version=1]|movedTo[version=1]">
                         <td>
                           <xsl:call-template name="Image">
                             <xsl:with-param name="version">version1</xsl:with-param>
                           </xsl:call-template>
                           <font color="maroon"/><xsl:element name="a"><xsl:attribute name="href">tlog:u2:#<xsl:value-of select="guid"/></xsl:attribute><xsl:value-of select="description"/></xsl:element>
                         </td>
	               </xsl:for-each>
                       <xsl:for-each select="created[version=2]|modified[version=2]|deleted[version=2]|movedFrom[version=2]|movedTo[version=2]">
                         <td>
                           <xsl:call-template name="Image">
                             <xsl:with-param name="version">version2</xsl:with-param>
                           </xsl:call-template>
                           <font color="maroon"/><xsl:element name="a"><xsl:attribute name="href">tlog:u2:#<xsl:value-of select="guid"/></xsl:attribute><xsl:value-of select="description"/></xsl:element>
                         </td>
                       </xsl:for-each>
                       <xsl:if test="$has-ancestor">
                        <td>
                          <xsl:for-each select="created[version=1]|modified[version=1]|deleted[version=1]|movedFrom[version=1]|movedTo[version=1]">
                            <xsl:call-template name="Image">
                              <xsl:with-param name="version">ancestor</xsl:with-param>
                            </xsl:call-template>
                          </xsl:for-each>
                        </td>
                       </xsl:if>
                       <xsl:if test="$has-ancestor2">
                        <td>
                          <xsl:for-each select="created[version=1]|modified[version=1]|deleted[version=1]|movedFrom[version=1]|movedTo[version=1]">
                            <xsl:call-template name="Image">
                              <xsl:with-param name="version">ancestor2</xsl:with-param>
                            </xsl:call-template>
                          </xsl:for-each>
                        </td>
                       </xsl:if>
                    </xsl:when>
                    <xsl:otherwise>
                      <xsl:if test = "version='2'">
                        <td>
                          <xsl:call-template name="Image">
                            <xsl:with-param name="version">version1</xsl:with-param>
                          </xsl:call-template>
                        </td>
                      </xsl:if>
                      <td>
                        <xsl:choose> 
                          <xsl:when test = "version='1'">
                            <xsl:call-template name="Image">
                              <xsl:with-param name="version">version1</xsl:with-param>
                            </xsl:call-template>
                          </xsl:when>
                          <xsl:otherwise>
                            <xsl:call-template name="Image">
                              <xsl:with-param name="version">version2</xsl:with-param>
                            </xsl:call-template>
                          </xsl:otherwise>
 		        </xsl:choose>
                        <xsl:element name="a"><xsl:attribute name="href">tlog:u2:#<xsl:value-of select="guid"/></xsl:attribute><xsl:value-of select="description"/></xsl:element>
                      </td>
                      <xsl:if test = "version='1'">
                        <td>
                          <xsl:call-template name="Image">
                            <xsl:with-param name="version">version2</xsl:with-param>
                          </xsl:call-template>
                        </td>
                      </xsl:if>
                      <xsl:if test="$has-ancestor">
                       <td>
                         <xsl:call-template name="Image">
                           <xsl:with-param name="version">ancestor</xsl:with-param>
                         </xsl:call-template>
                       </td>
                      </xsl:if>
                      <xsl:if test="$has-ancestor2">
                       <td>
                         <xsl:call-template name="Image">
                           <xsl:with-param name="version">ancestor2</xsl:with-param>
                         </xsl:call-template>
                       </td>
                      </xsl:if>
                    </xsl:otherwise>
                 </xsl:choose>
              </tr>
          </xsl:for-each>
        </xsl:for-each>
        <xsl:for-each select="created|modified|deleted|movedFrom|movedTo|conflict">
          <tr>
            <td><xsl:value-of select="@id"/></td>
            <td>
               <xsl:value-of select="description"/>
            </td>
            <xsl:choose>
               <xsl:when test = "local-name()='conflict'">
                 <td>
                   <xsl:for-each select="created[version=1]|modified[version=1]|deleted[version=1]|movedFrom[version=1]|movedTo[version=1]">
                     <xsl:call-template name="Image">
                       <xsl:with-param name="version">version1</xsl:with-param>
                     </xsl:call-template>
                     <font color="maroon"/><xsl:element name="a"><xsl:attribute name="href">tlog:u2:#<xsl:value-of select="guid"/></xsl:attribute><xsl:value-of select="description"/></xsl:element>
                   </xsl:for-each>
                 </td>
                 <xsl:for-each select="created[version=2]|modified[version=2]|deleted[version=2]|movedFrom[version=2]|movedTo[version=2]">
                   <td>
                     <xsl:call-template name="Image">
                       <xsl:with-param name="version">version2</xsl:with-param>
                     </xsl:call-template>
                     <font color="maroon"/><xsl:element name="a"><xsl:attribute name="href">tlog:u2:#<xsl:value-of select="guid"/></xsl:attribute><xsl:value-of select="description"/></xsl:element>
                   </td>
                 </xsl:for-each>
                 <xsl:if test="$has-ancestor">
                  <td>
                    <xsl:for-each select="created[version=1]|modified[version=1]|deleted[version=1]|movedFrom[version=1]|movedTo[version=1]">
                      <xsl:call-template name="Image">
                        <xsl:with-param name="version">ancestor</xsl:with-param>
                      </xsl:call-template>
                    </xsl:for-each>
                  </td>
                 </xsl:if>
                 <xsl:if test="$has-ancestor2">
                  <td>
                    <xsl:for-each select="created[version=1]|modified[version=1]|deleted[version=1]|movedFrom[version=1]|movedTo[version=1]">
                      <xsl:call-template name="Image">
                        <xsl:with-param name="version">ancestor2</xsl:with-param>
                      </xsl:call-template>
                    </xsl:for-each>
                  </td>
                 </xsl:if>
               </xsl:when>
               <xsl:otherwise>
                  <xsl:if test = "version='2'">
                     <td>
                       <xsl:call-template name="Image">
                         <xsl:with-param name="version">version1</xsl:with-param>
                       </xsl:call-template>
                     </td>
                  </xsl:if>
                  <td>
                    <xsl:choose> 
                      <xsl:when test = "version='1'">
                        <xsl:call-template name="Image">
                          <xsl:with-param name="version">version1</xsl:with-param>
                        </xsl:call-template>
                      </xsl:when>
                      <xsl:otherwise>
                        <xsl:call-template name="Image">
                          <xsl:with-param name="version">version2</xsl:with-param>
                        </xsl:call-template>
                      </xsl:otherwise>
 		    </xsl:choose>
                    <xsl:element name="a"><xsl:attribute name="href">tlog:u2:#<xsl:value-of select="guid"/></xsl:attribute><xsl:value-of select="description"/></xsl:element>
                  </td>
                  <xsl:if test = "version='1'">
                     <td>
                       <xsl:call-template name="Image">
                         <xsl:with-param name="version">version2</xsl:with-param>
                       </xsl:call-template>
                     </td>
                  </xsl:if>
                  <xsl:if test="$has-ancestor">
                   <td>
                     <xsl:call-template name="Image">
                       <xsl:with-param name="version">ancestor</xsl:with-param>
                     </xsl:call-template>
                   </td>
                  </xsl:if>
                  <xsl:if test="$has-ancestor2">
                   <td>
                     <xsl:call-template name="Image">
                       <xsl:with-param name="version">ancestor2</xsl:with-param>
                     </xsl:call-template>
                   </td>
                  </xsl:if>
               </xsl:otherwise>
            </xsl:choose>
          </tr>
        </xsl:for-each>
      </table>
    </xsl:for-each>
    <xsl:for-each select="/report/diagram-compare/no-representation">
      <h2>Differences without graphical representation</h2>
      <table border="1" cellpadding="2" cellspacing="0" frame = "box">
        <tr>
          <th>Id</th>
          <th>Diff</th>
          <th>Version 1</th>
          <th>Version 2</th>
          <xsl:if test="$has-ancestor">
            <th>Ancestor</th>
          </xsl:if>
          <xsl:if test="$has-ancestor2">
            <th>Alternative Ancestor</th>
          </xsl:if>
        </tr>
        <xsl:for-each select="composite-difference">
           <tr>
              <td rowspan="{count(created|modified|deleted|movedFrom|movedTo|conflict)+1}"><xsl:value-of select="@id"/></td>
              <td rowspan="{count(created|modified|deleted|movedFrom|movedTo|conflict)+1}"><xsl:value-of select="description"/></td>
           </tr>
           <xsl:for-each select="created|modified|deleted|movedFrom|movedTo|conflict">
              <tr>
                 <xsl:choose>
                    <xsl:when test = "local-name()='conflict'">
                       <xsl:for-each select="created[version=1]|modified[version=1]|deleted[version=1]|movedFrom[version=1]|movedTo[version=1]">
                         <td>
                           <xsl:call-template name="Text">
                             <xsl:with-param name="version">version1</xsl:with-param>
                           </xsl:call-template>
                           <font color="maroon"/><xsl:element name="a"><xsl:attribute name="href">tlog:u2:#<xsl:value-of select="guid"/></xsl:attribute><xsl:value-of select="description"/></xsl:element>
                         </td>
	               </xsl:for-each>
                       <xsl:for-each select="created[version=2]|modified[version=2]|deleted[version=2]|movedFrom[version=2]|movedTo[version=2]">
                         <td>
                           <xsl:call-template name="Text">
                             <xsl:with-param name="version">version2</xsl:with-param>
                           </xsl:call-template>
                           <font color="maroon"/><xsl:element name="a"><xsl:attribute name="href">tlog:u2:#<xsl:value-of select="guid"/></xsl:attribute><xsl:value-of select="description"/></xsl:element>
                         </td>
                       </xsl:for-each>
                       <xsl:if test="$has-ancestor">
                        <td>
                          <xsl:for-each select="created[version=1]|modified[version=1]|deleted[version=1]|movedFrom[version=1]|movedTo[version=1]">
                            <xsl:call-template name="Text">
                              <xsl:with-param name="version">ancestor</xsl:with-param>
                            </xsl:call-template>
                          </xsl:for-each>
                        </td>
                       </xsl:if>
                       <xsl:if test="$has-ancestor2">
                        <td>
                          <xsl:for-each select="created[version=1]|modified[version=1]|deleted[version=1]|movedFrom[version=1]|movedTo[version=1]">
                            <xsl:call-template name="Text">
                              <xsl:with-param name="version">ancestor2</xsl:with-param>
                            </xsl:call-template>
                          </xsl:for-each>
                        </td>
                       </xsl:if>
                    </xsl:when>
                    <xsl:otherwise>
                      <xsl:if test = "version='2'">
                        <td>
                          <xsl:call-template name="Text">
                            <xsl:with-param name="version">version1</xsl:with-param>
                          </xsl:call-template>
                        </td>
                      </xsl:if>
                      <td>
                        <xsl:choose> 
                          <xsl:when test = "version='1'">
                            <xsl:call-template name="Text">
                              <xsl:with-param name="version">version1</xsl:with-param>
                            </xsl:call-template>
                          </xsl:when>
                          <xsl:otherwise>
                            <xsl:call-template name="Text">
                              <xsl:with-param name="version">version2</xsl:with-param>
                            </xsl:call-template>
                          </xsl:otherwise>
 		        </xsl:choose>
                        <xsl:element name="a"><xsl:attribute name="href">tlog:u2:#<xsl:value-of select="guid"/></xsl:attribute><xsl:value-of select="description"/></xsl:element>
                      </td>
                      <xsl:if test = "version='1'">
                        <td>
                          <xsl:call-template name="Text">
                            <xsl:with-param name="version">version2</xsl:with-param>
                          </xsl:call-template>
                        </td>
                      </xsl:if>
                      <xsl:if test="$has-ancestor">
                       <td>
                         <xsl:call-template name="Text">
                           <xsl:with-param name="version">ancestor</xsl:with-param>
                         </xsl:call-template>
                       </td>
                      </xsl:if>
                      <xsl:if test="$has-ancestor2">
                       <td>
                         <xsl:call-template name="Text">
                           <xsl:with-param name="version">ancestor2</xsl:with-param>
                         </xsl:call-template>
                       </td>
                      </xsl:if>
                    </xsl:otherwise>
                 </xsl:choose>
              </tr>
          </xsl:for-each>
        </xsl:for-each>
        <xsl:for-each select="created|modified|deleted|movedFrom|movedTo|conflict">
          <tr>
            <td><xsl:value-of select="@id"/></td>
            <td>
               <xsl:value-of select="description"/>
            </td>
            <xsl:choose>
               <xsl:when test = "local-name()='conflict'">
                 <td>
                   <xsl:for-each select="created[version=1]|modified[version=1]|deleted[version=1]|movedFrom[version=1]|movedTo[version=1]">
                     <xsl:call-template name="Text">
                       <xsl:with-param name="version">version1</xsl:with-param>
                     </xsl:call-template>
                     <font color="maroon"/><xsl:element name="a"><xsl:attribute name="href">tlog:u2:#<xsl:value-of select="guid"/></xsl:attribute><xsl:value-of select="description"/></xsl:element>
                   </xsl:for-each>
                 </td>
                 <xsl:for-each select="created[version=2]|modified[version=2]|deleted[version=2]|movedFrom[version=2]|movedTo[version=2]">
                   <td>
                     <xsl:call-template name="Text">
                       <xsl:with-param name="version">version2</xsl:with-param>
                     </xsl:call-template>
                     <font color="maroon"/><xsl:element name="a"><xsl:attribute name="href">tlog:u2:#<xsl:value-of select="guid"/></xsl:attribute><xsl:value-of select="description"/></xsl:element>
                   </td>
                 </xsl:for-each>
                 <xsl:if test="$has-ancestor">
                  <td>
                    <xsl:for-each select="created[version=1]|modified[version=1]|deleted[version=1]|movedFrom[version=1]|movedTo[version=1]">
                      <xsl:call-template name="Text">
                        <xsl:with-param name="version">ancestor</xsl:with-param>
                      </xsl:call-template>
                    </xsl:for-each>
                  </td>
                 </xsl:if>
                 <xsl:if test="$has-ancestor2">
                  <td>
                    <xsl:for-each select="created[version=1]|modified[version=1]|deleted[version=1]|movedFrom[version=1]|movedTo[version=1]">
                      <xsl:call-template name="Text">
                        <xsl:with-param name="version">ancestor2</xsl:with-param>
                      </xsl:call-template>
                    </xsl:for-each>
                  </td>
                 </xsl:if>
               </xsl:when>
               <xsl:otherwise>
                  <xsl:if test = "version='2'">
                     <td>
                       <xsl:call-template name="Text">
                         <xsl:with-param name="version">version1</xsl:with-param>
                       </xsl:call-template>
                     </td>
                  </xsl:if>
                  <td>
                    <xsl:choose> 
                      <xsl:when test = "version='1'">
                        <xsl:call-template name="Text">
                          <xsl:with-param name="version">version1</xsl:with-param>
                        </xsl:call-template>
                      </xsl:when>
                      <xsl:otherwise>
                        <xsl:call-template name="Text">
                          <xsl:with-param name="version">version2</xsl:with-param>
                        </xsl:call-template>
                      </xsl:otherwise>
 		    </xsl:choose>
                    <xsl:element name="a"><xsl:attribute name="href">tlog:u2:#<xsl:value-of select="guid"/></xsl:attribute><xsl:value-of select="description"/></xsl:element>
                  </td>
                  <xsl:if test = "version='1'">
                     <td>
                       <xsl:call-template name="Text">
                         <xsl:with-param name="version">version2</xsl:with-param>
                       </xsl:call-template>
                     </td>
                  </xsl:if>
                  <xsl:if test="$has-ancestor">
                   <td>
                     <xsl:call-template name="Text">
                       <xsl:with-param name="version">ancestor</xsl:with-param>
                     </xsl:call-template>
                   </td>
                  </xsl:if>
                  <xsl:if test="$has-ancestor2">
                   <td>
                     <xsl:call-template name="Text">
                       <xsl:with-param name="version">ancestor2</xsl:with-param>
                     </xsl:call-template>
                   </td>
                  </xsl:if>
               </xsl:otherwise>
            </xsl:choose>
          </tr>
        </xsl:for-each>
      </table>
    </xsl:for-each>
</body>
</html>
</xsl:template>
</xsl:stylesheet>
